==> nextcloud-31.0.10.tar.bz2: nextcloud/apps/systemtags/l10n/fr.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "L'étiquette système %1$s a été ajoutée par le système.",
    "Added system tag {systemtag}" : "Étiquette système {systemtag} ajoutée",
    "Added system tag %1$s" : "Étiquette système %1$s ajoutée",
    "%1$s added system tag %2$s" : "%1$s a ajouté l'étiquette système %2$s",
    "{actor} added system tag {systemtag}" : "{actor} a ajouté l'étiquette collaborative {systemtag}",
    "System tag %1$s removed by the system" : "L'étiquette système %1$s a été retirée par le système.",
    "Removed system tag {systemtag}" : "Étiquette système {systemtag} retirée",
    "Removed system tag %1$s" : "Étiquette système %1$s retirée",
    "%1$s removed system tag %2$s" : "%1$s a retiré l'étiquette système %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} a retiré l'étiquette système {systemtag}",
    "You created system tag %1$s" : "Vous avez créé l'étiquette système %1$s",
    "You created system tag {systemtag}" : "Vous avez créé l'étiquette système {systemtag}",
    "%1$s created system tag %2$s" : "%1$s a créé l'étiquette système %2$s",
    "{actor} created system tag {systemtag}" : "{actor} a créé l'étiquette système {systemtag}",
    "You deleted system tag %1$s" : "Vous avez supprimé l'étiquette système %1$s",
    "You deleted system tag {systemtag}" : "Vous avez supprimé l'étiquette système {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s a supprimé l'étiquette système %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} a supprimé l'étiquette système {systemtag}",
    "You updated system tag %2$s to %1$s" : "Vous avez renommé l'étiquette système %2$s en %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Vous avez renommé l'étiquette système {oldsystemtag} en {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s a renommé l'étiquette système %3$s en %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} a renommé l'étiquette système {oldsystemtag} en {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "L'étiquette système %2$s a été ajoutée à %1$s par le système.",
    "System tag {systemtag} was added to {file} by the system" : "L'étiquette système {systemtag} a été ajoutée à {file} par le système",
    "You added system tag %2$s to %1$s" : "Vous avez ajouté l'étiquette système %2$s à %1$s",
    "You added system tag {systemtag} to {file}" : "Vous avez ajouté l'étiquette système {systemtag} à {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s a ajouté l'étiquette système %3$s à %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} a ajouté l'étiquette système {systemtag} à {file}",
    "System tag %2$s was removed from %1$s by the system" : "L'étiquette système %2$s a été retirée de %1$s par le système",
    "System tag {systemtag} was removed from {file} by the system" : "L'étiquette système {systemtag} a été retirée de {file} par le système",
    "You removed system tag %2$s from %1$s" : "Vous avez retiré l'étiquette système %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Vous avez retiré l'étiquette système {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s a retiré l'étiquette système %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} a retiré l'étiquette système {systemtag} de {file}",
    "%s (restricted)" : "%s (restreinte)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Les étiquettes système</strong> d'un fichier ont été modifiées",
    "Files" : "Fichiers",
    "Tags" : "Étiquettes",
    "All tagged %s …" : "Tous étiquetés %s …",
    "tagged %s" : "étiqueté %s",
    "Collaborative tags" : "Étiquettes collaboratives ",
    "Collaborative tagging functionality which shares tags among people." : "Fonctionnalité d'étiquetage collaboratif qui permet de partager des étiquettes entre plusieurs personnes.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Fonctionnalité d'étiquettes collaboratives qui partage les étiquettes entre les personnes. Génial pour les équipes.\n\t(Si vous êtes un fournisseur avec plusieurs installations, il est conseillé de désactiver cette application, car sinon les étiquettes seront partagées)",
    "Public" : "Publique",
    "Restricted" : "Restreinte",
    "Invisible" : "Invisible",
    "Created tag" : "Étiquette créée",
    "Failed to create tag" : "Impossible de créer l'étiquette",
    "Updated tag" : "Étiquette mise à jour",
    "Failed to update tag" : "Impossible de mettre à jour l'étiquette",
    "Deleted tag" : "Étiquette supprimée",
    "Failed to delete tag" : "Impossible de supprimer l'étiquette",
    "Create or edit tags" : "Créer ou modifier les étiquettes",
    "Search for a tag to edit" : "Rechercher une étiquette à modifier",
    "No tags to select" : "Aucune étiquette à sélectionner",
    "Tag name" : "Nom de l'étiquette",
    "Tag level" : "Niveau de l'étiquette",
    "Create" : "Créer",
    "Update" : "Mise à jour",
    "Delete" : "Supprimer",
    "Reset" : "Réinitialiser",
    "Loading …" : "Chargement...",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} sera attribuée et {tag2} sera retirée d'1 fichier.","{tag1} sera attribuée et {tag2} sera retirée de {count} fichiers.","{tag1} sera attribuée et {tag2} sera retirée de {count} fichiers."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} sera attribuée à 1 fichier.","{tag} sera attribuée à {count} fichiers.","{tag} sera attribuée à {count} fichiers."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} sera retiré d'1 fichier.","{tag} sera retirée de {count} fichiers.","{tag} sera retirée de {count} fichiers."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} et {lastTag} seront attribuées à 1 fichier.","{tags} et {lastTag} seront attribuées à {count} fichiers.","{tags} et {lastTag} seront attribuées à {count} fichiers."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} et {lastTag} seront retirées d'1 fichier.","{tags} et {lastTag} seront retirées de {count} fichiers.","{tags} et {lastTag} seront retirées de {count} fichiers."],
    "{displayName} (hidden)" : "{displayName} (caché)",
    "{displayName} (restricted)" : "{displayName} (restreint)",
    "Only admins can create new tags" : "Seuls les administrateurs peuvent créer de nouvelles étiquettes",
    "Failed to apply tags changes" : "Échec de lors d'application des étiquettes",
    "Manage tags" : "Gérer les étiquettes",
    "Applying tags changes…" : "Application des changements d'étiquettes…",
    "Search or create tag" : "Rechercher ou créer une étiquette",
    "Search tag" : "Rechercher une étiquette",
    "Change tag color" : "Changer la couleur de l'étiquette",
    "Create new tag" : "Créer une nouvelle étiquette",
    "Choose tags for the selected files" : "Choisir des étiquettes pour les fichiers sélectionnés",
    "Cancel" : "Annuler",
    "Apply" : "Appliquer",
    "Failed to load selected tags" : "Impossible de charger les étiquettes sélectionnées",
    "Failed to load tags" : "Impossible de charger les étiquettes",
    "Failed to select tag" : "Impossible de sélectionner l'étiquette",
    "System admin disabled tag creation. You can only use existing ones." : "L'administrateur a désactivé la création d'étiquettes. Vous ne pouvez utiliser que les étiquettes existantes.",
    "Search or create collaborative tags" : "Rechercher ou créer des étiquettes collaboratives",
    "No tags to select, type to create a new tag" : "Aucune étiquette à sélectionner, entrez une nouvelle étiquette",
    "Unable to update setting" : "Impossible de mettre à jour les paramètres",
    "System tag creation is now restricted to administrators" : "La création d'étiquettes système est désormais réservée aux administrateurs",
    "System tag creation is now allowed for everybody" : "La création d'étiquettes système est désormais autorisée pour tout le monde",
    "System tag management" : "Gestion des étiquettes système",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Si cette option est activée, seuls les administrateurs peuvent créer et modifier des étiquettes. Les comptes peuvent toujours les attribuer et les retirer des fichiers.",
    "Restrict tag creation and editing to administrators" : "Restreindre la création et la modification des étiquettes aux administrateurs",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les étiquettes collaboratives sont disponibles pour tous les utilisateurs. Les étiquettes restreintes sont visibles par les utilisateurs, mais ne peuvent pas être attribuées par eux. Les étiquettes invisibles sont à usage interne, car les utilisateurs ne peuvent pas les voir ou les attribuer.",
    "Assigned collaborative tags" : "Étiquettes collaboratives attribuées",
    "Open in Files" : "Ouvrir dans Fichiers",
    "List of tags and their associated files and folders." : "Liste des étiquettes et leurs fichiers et dossiers associés.",
    "No tags found" : "Aucune étiquette trouvée",
    "Tags you have created will show up here." : "Les étiquettes que vous avez créées apparaîtront ici.",
    "Failed to load tag" : "Échec du chargement de l'étiquette",
    "Failed to load last used tags" : "Impossible de charger les dernières étiquettes utilisées",
    "Missing \"Content-Location\" header" : "Entête \"Contenu-Localisation\" manquant",
    "A tag with the same name already exists" : "Une étiquette portant le même nom existe déjà",
    "Failed to load tags for file" : "Impossible de charger les étiquettes du fichier",
    "Failed to set tag for file" : "Impossible d'attribuer l'étiquette au fichier",
    "Failed to delete tag for file" : "Impossible de supprimer l'étiquette au fichier",
    "Collaborative tags …" : "Étiquettes collaboratives…",
    "Loading …" : "Chargement…",
    "File tags modification canceled" : "Modification des étiquettes du fichier annulée",
    "Select or create tags to apply to all selected files" : "Sélectionnez ou créez des étiquettes à appliquer à tous les fichiers sélectionnés",
    "Select tags to apply to all selected files" : "Sélectionnez les étiquettes à appliquer à tous les fichiers sélectionnés",
    "Apply changes" : "Appliquer les modifications",
    "Loading collaborative tags …" : "Chargement des étiquettes collaboratives..."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.11.tar.bz2: nextcloud/apps/systemtags/l10n/fr.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "L'étiquette système %1$s a été ajoutée par le système.",
    "Added system tag {systemtag}" : "Étiquette système {systemtag} ajoutée",
    "Added system tag %1$s" : "Étiquette système %1$s ajoutée",
    "%1$s added system tag %2$s" : "%1$s a ajouté l'étiquette système %2$s",
    "{actor} added system tag {systemtag}" : "{actor} a ajouté l'étiquette collaborative {systemtag}",
    "System tag %1$s removed by the system" : "L'étiquette système %1$s a été retirée par le système.",
    "Removed system tag {systemtag}" : "Étiquette système {systemtag} retirée",
    "Removed system tag %1$s" : "Étiquette système %1$s retirée",
    "%1$s removed system tag %2$s" : "%1$s a retiré l'étiquette système %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} a retiré l'étiquette système {systemtag}",
    "You created system tag %1$s" : "Vous avez créé l'étiquette système %1$s",
    "You created system tag {systemtag}" : "Vous avez créé l'étiquette système {systemtag}",
    "%1$s created system tag %2$s" : "%1$s a créé l'étiquette système %2$s",
    "{actor} created system tag {systemtag}" : "{actor} a créé l'étiquette système {systemtag}",
    "You deleted system tag %1$s" : "Vous avez supprimé l'étiquette système %1$s",
    "You deleted system tag {systemtag}" : "Vous avez supprimé l'étiquette système {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s a supprimé l'étiquette système %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} a supprimé l'étiquette système {systemtag}",
    "You updated system tag %2$s to %1$s" : "Vous avez renommé l'étiquette système %2$s en %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Vous avez renommé l'étiquette système {oldsystemtag} en {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s a renommé l'étiquette système %3$s en %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} a renommé l'étiquette système {oldsystemtag} en {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "L'étiquette système %2$s a été ajoutée à %1$s par le système.",
    "System tag {systemtag} was added to {file} by the system" : "L'étiquette système {systemtag} a été ajoutée à {file} par le système",
    "You added system tag %2$s to %1$s" : "Vous avez ajouté l'étiquette système %2$s à %1$s",
    "You added system tag {systemtag} to {file}" : "Vous avez ajouté l'étiquette système {systemtag} à {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s a ajouté l'étiquette système %3$s à %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} a ajouté l'étiquette système {systemtag} à {file}",
    "System tag %2$s was removed from %1$s by the system" : "L'étiquette système %2$s a été retirée de %1$s par le système",
    "System tag {systemtag} was removed from {file} by the system" : "L'étiquette système {systemtag} a été retirée de {file} par le système",
    "You removed system tag %2$s from %1$s" : "Vous avez retiré l'étiquette système %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Vous avez retiré l'étiquette système {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s a retiré l'étiquette système %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} a retiré l'étiquette système {systemtag} de {file}",
    "%s (restricted)" : "%s (restreinte)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Les étiquettes système</strong> d'un fichier ont été modifiées",
    "Files" : "Fichiers",
    "Tags" : "Étiquettes",
    "All tagged %s …" : "Tous étiquetés %s …",
    "tagged %s" : "étiqueté %s",
    "Collaborative tags" : "Étiquettes collaboratives ",
    "Collaborative tagging functionality which shares tags among people." : "Fonctionnalité d'étiquetage collaboratif qui permet de partager des étiquettes entre plusieurs personnes.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Fonctionnalité d'étiquettes collaboratives qui partage les étiquettes entre les personnes. Génial pour les équipes.\n\t(Si vous êtes un fournisseur avec plusieurs installations, il est conseillé de désactiver cette application, car sinon les étiquettes seront partagées)",
    "Public" : "Publique",
    "Restricted" : "Restreinte",
    "Invisible" : "Invisible",
    "Created tag" : "Étiquette créée",
    "Failed to create tag" : "Impossible de créer l'étiquette",
    "Updated tag" : "Étiquette mise à jour",
    "Failed to update tag" : "Impossible de mettre à jour l'étiquette",
    "Deleted tag" : "Étiquette supprimée",
    "Failed to delete tag" : "Impossible de supprimer l'étiquette",
    "Create or edit tags" : "Créer ou modifier les étiquettes",
    "Search for a tag to edit" : "Rechercher une étiquette à modifier",
    "Collaborative tags …" : "Étiquettes collaboratives  …",
    "No tags to select" : "Aucune étiquette à sélectionner",
    "Tag name" : "Nom de l'étiquette",
    "Tag level" : "Niveau de l'étiquette",
    "Create" : "Créer",
    "Update" : "Mise à jour",
    "Delete" : "Supprimer",
    "Reset" : "Réinitialiser",
    "Loading …" : "Chargement...",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} sera attribuée et {tag2} sera retirée d'1 fichier.","{tag1} sera attribuée et {tag2} sera retirée de {count} fichiers.","{tag1} sera attribuée et {tag2} sera retirée de {count} fichiers."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} sera attribuée à 1 fichier.","{tag} sera attribuée à {count} fichiers.","{tag} sera attribuée à {count} fichiers."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} sera retiré d'1 fichier.","{tag} sera retirée de {count} fichiers.","{tag} sera retirée de {count} fichiers."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} et {lastTag} seront attribuées à 1 fichier.","{tags} et {lastTag} seront attribuées à {count} fichiers.","{tags} et {lastTag} seront attribuées à {count} fichiers."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} et {lastTag} seront retirées d'1 fichier.","{tags} et {lastTag} seront retirées de {count} fichiers.","{tags} et {lastTag} seront retirées de {count} fichiers."],
    "{displayName} (hidden)" : "{displayName} (caché)",
    "{displayName} (restricted)" : "{displayName} (restreint)",
    "Only admins can create new tags" : "Seuls les administrateurs peuvent créer de nouvelles étiquettes",
    "Failed to apply tags changes" : "Échec de lors d'application des étiquettes",
    "Manage tags" : "Gérer les étiquettes",
    "Applying tags changes…" : "Application des changements d'étiquettes…",
    "Search or create tag" : "Rechercher ou créer une étiquette",
    "Search tag" : "Rechercher une étiquette",
    "Change tag color" : "Changer la couleur de l'étiquette",
    "Create new tag" : "Créer une nouvelle étiquette",
    "Choose tags for the selected files" : "Choisir des étiquettes pour les fichiers sélectionnés",
    "Cancel" : "Annuler",
    "Apply" : "Appliquer",
    "Failed to load selected tags" : "Impossible de charger les étiquettes sélectionnées",
    "Failed to load tags" : "Impossible de charger les étiquettes",
    "Failed to select tag" : "Impossible de sélectionner l'étiquette",
    "System admin disabled tag creation. You can only use existing ones." : "L'administrateur a désactivé la création d'étiquettes. Vous ne pouvez utiliser que les étiquettes existantes.",
    "Loading collaborative tags …" : "Chargement des étiquettes collaboratives  ...",
    "Search or create collaborative tags" : "Rechercher ou créer des étiquettes collaboratives",
    "No tags to select, type to create a new tag" : "Aucune étiquette à sélectionner, entrez une nouvelle étiquette",
    "Unable to update setting" : "Impossible de mettre à jour les paramètres",
    "System tag creation is now restricted to administrators" : "La création d'étiquettes système est désormais réservée aux administrateurs",
    "System tag creation is now allowed for everybody" : "La création d'étiquettes système est désormais autorisée pour tout le monde",
    "System tag management" : "Gestion des étiquettes système",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Si cette option est activée, seuls les administrateurs peuvent créer et modifier des étiquettes. Les comptes peuvent toujours les attribuer et les retirer des fichiers.",
    "Restrict tag creation and editing to administrators" : "Restreindre la création et la modification des étiquettes aux administrateurs",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les étiquettes collaboratives sont disponibles pour tous les utilisateurs. Les étiquettes restreintes sont visibles par les utilisateurs, mais ne peuvent pas être attribuées par eux. Les étiquettes invisibles sont à usage interne, car les utilisateurs ne peuvent pas les voir ou les attribuer.",
    "Assigned collaborative tags" : "Étiquettes collaboratives attribuées",
    "Open in Files" : "Ouvrir dans Fichiers",
    "List of tags and their associated files and folders." : "Liste des étiquettes et leurs fichiers et dossiers associés.",
    "No tags found" : "Aucunes étiquettes trouvées",
    "Tags you have created will show up here." : "Les étiquettes que vous avez créées apparaîtront ici.",
    "Failed to load tag" : "Échec du chargement de l'étiquette",
    "Failed to load last used tags" : "Impossible de charger les dernières étiquettes utilisées",
    "Missing \"Content-Location\" header" : "Entête \"Contenu-Localisation\" manquant",
    "A tag with the same name already exists" : "Une étiquette portant le même nom existe déjà",
    "Failed to load tags for file" : "Impossible de charger les étiquettes du fichier",
    "Failed to set tag for file" : "Impossible d'attribuer l'étiquette au fichier",
    "Failed to delete tag for file" : "Impossible de supprimer l'étiquette au fichier",
    "Collaborative tags …" : "Étiquettes collaboratives…",
    "Loading …" : "Chargement…",
    "File tags modification canceled" : "Modification des étiquettes du fichier annulée",
    "Select or create tags to apply to all selected files" : "Sélectionnez ou créez des étiquettes à appliquer à tous les fichiers sélectionnés",
    "Select tags to apply to all selected files" : "Sélectionnez les étiquettes à appliquer à tous les fichiers sélectionnés",
    "Apply changes" : "Appliquer les modifications",
    "Loading collaborative tags …" : "Chargement des étiquettes collaboratives..."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
